- 1. DrDu

     > Lieber Hendrik,
     > kannst Du hierzu was beitragen?
     > Ich finde keinen rechten Grund, warum sich der Impuls als p->p-mv unter Galilei-Boosts transformiert, Lz ->Lz.
     > https://www.physicsforums.com/threads/what-is-the-suitable-unitary-operator-for-a-rotating-frame.780800/

     Nov 26, 2014
     1. Swapnil Das likes this.
     2. Dirac62

        > hi

        Sep 18, 2015
  Show Ignored Content
- Loading...
- Loading...

- ### About

  Gender:
    Male
  Home Page:
    http://fias.uni-frankfurt.de/~hees/
  Location:
    Frankfurt/Main, Germany
  Occupation:
    Postdoc at Goethe Universtity Frankfurt (Germany)
  Educational Background:
    PhD
  Degree in:
    Relativistic Heavy-Ion Physics (Theory)
  Favorite Area of Science:
    Physics/Math
  Classical Music (Piano, Choir)

  ### Interact

  Content:
    - Find all content by vanhees71
    - Find all threads by vanhees71
- Loading...

777 888